@@ -1,9 +1,11 @@
 numeric_FisherInformation <- function(model){
   model <- expectedmodel(model)
-  2 * sum(model@sample@groups$nobs) * numDeriv::jacobian(psychonetrics_gradient,parVector(model),model=model)
+  # 2 * sum(model@sample@groups$nobs) * numDeriv::jacobian(psychonetrics_gradient,parVector(model),model=model)
+  
+  # Unit information instead:
+  0.5 * numDeriv::jacobian(psychonetrics_gradient,parVector(model),model=model)
 }
 
-
 # General Fisher information former:
 psychonetrics_FisherInformation <- function(model, analytic = TRUE){
   # Maybe do numeric?
@@ -56,7 +58,8 @@ psychonetrics_FisherInformation <- function(model, analytic = TRUE){
     "var1" = d_phi_theta_var1,
     # "panelvar1" = d_phi_theta_panelvar1,
     "dlvm1" = d_phi_theta_dlvm1,
-    "tsdlvm1" = d_phi_theta_tsdlvm1
+    "tsdlvm1" = d_phi_theta_tsdlvm1,
+    "meta_varcov" = d_phi_theta_meta_varcov
     # "cholesky" = d_phi_theta_cholesky
   )
   modelPart <- modelJacobian(prep)
@@ -65,7 +68,11 @@ psychonetrics_FisherInformation <- function(model, analytic = TRUE){
   manualPart <- Mmatrix(model@parameters)
 
   # Compute fisher information and return:
-  Fisher <- 2 * prep$nTotal * t(manualPart) %*% t(modelPart) %*% estimatorPartHessian %*% modelPart %*% manualPart
+  # Fisher <- 2 * prep$nTotal * t(manualPart) %*% t(modelPart) %*% estimatorPartHessian %*% modelPart %*% manualPart
+
+  # Unit information instead:
+  Fisher <- 0.5 * t(manualPart) %*% t(modelPart) %*% estimatorPartHessian %*% modelPart %*% manualPart
+  
   as.matrix(Fisher)
 }
 # 
